#' Eez Coefficients
#'
#' Predictor feature coefficients as published in paper.
#'
#' @format eez_rg data.frame with 2 variables: \code{geneName}, \code{coef}
"eez_rg"


#' port position
#'
#' define the position of port in the world
#'
#' @format port_sf data.frame with 2 variables: \code{row.names}, \code{id}
"port_sf"
